@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #include <QObject>
 #include <QNetworkReply>
 class QNetworkAccessManager;
-class KComboBox;
+class QComboBox;
 class QNetworkReply;
 
 namespace PimCommon {
@@ -35,7 +35,7 @@ public:
 
     void setParentWidget(QWidget *parent);
 
-    Q_REQUIRED_RESULT QMap<QString, QMap<QString, QString> > initListLanguage(KComboBox *from);
+    Q_REQUIRED_RESULT QMap<QString, QMap<QString, QString> > initListLanguage(QComboBox *from);
     void translate();
     void debug();
     void clear();
