@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -99,7 +99,7 @@ CollectionAclWidget::CollectionAclWidget(QWidget *parent)
 
     QWidget *buttonBox = new QWidget;
     QVBoxLayout *buttonBoxVBoxLayout = new QVBoxLayout(buttonBox);
-    buttonBoxVBoxLayout->setMargin(0);
+    buttonBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(buttonBox);
 
     ActionButton *button = new ActionButton(buttonBox);
